﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

using System.Collections.Generic;
using Silk.NET.SDL;

namespace Silk.NET.Input.Sdl
{
    partial class SdlKeyboard
    {
        private static readonly Dictionary<KeyCode, Key> _keyMap = new Dictionary<KeyCode, Key>
        {
            // The key enum was designed for UK-style QWERTY keyboards, thus some enumerants are missing if they require
            // a modifier key (such as a shift) in order to access that key

            {KeyCode.KUnknown, Key.Unknown},
            {KeyCode.KReturn, Key.Enter},
            {KeyCode.KEscape, Key.Escape},
            {KeyCode.KBackspace, Key.Backspace},
            {KeyCode.KTab, Key.Tab},
            {KeyCode.KSpace, Key.Space},
            //{KeyCode.KExclaim, Key.Exclaim},
            //{KeyCode.KQuotedbl, Key.Quotedbl},
            //{KeyCode.KHash, Key.Hash},
            //{KeyCode.KPercent, Key.Percent},
            //{KeyCode.KDollar, Key.Dollar},
            //{KeyCode.KAmpersand, Key.Ampersand},
            //{KeyCode.KQuote, Key.Quote},
            //{KeyCode.KLeftparen, Key.Leftparen},
            //{KeyCode.KRightparen, Key.Rightparen},
            //{KeyCode.KAsterisk, Key.Asterisk},
            //{KeyCode.KPlus, Key.Add},
            {KeyCode.KComma, Key.Comma},
            {KeyCode.KMinus, Key.Minus},
            {KeyCode.KPeriod, Key.Period},
            {KeyCode.KSlash, Key.Slash},
            {KeyCode.K0, Key.Number0},
            {KeyCode.K1, Key.Number1},
            {KeyCode.K2, Key.Number2},
            {KeyCode.K3, Key.Number3},
            {KeyCode.K4, Key.Number4},
            {KeyCode.K5, Key.Number5},
            {KeyCode.K6, Key.Number6},
            {KeyCode.K7, Key.Number7},
            {KeyCode.K8, Key.Number8},
            {KeyCode.K9, Key.Number9},
            //{KeyCode.KColon, Key.Colon},
            {KeyCode.KSemicolon, Key.Semicolon},
            //{KeyCode.KLess, Key.Less},
            {KeyCode.KEquals, Key.Equal},
            //{KeyCode.KGreater, Key.Greater},
            //{KeyCode.KQuestion, Key.Question},
            //{KeyCode.KAT, Key.AT},
            {KeyCode.KLeftbracket, Key.LeftBracket},
            {KeyCode.KBackslash, Key.BackSlash},
            {KeyCode.KRightbracket, Key.RightBracket},
            //{KeyCode.KCaret, Key.Caret},
            //{KeyCode.KUnderscore, Key.Underscore},
            //{KeyCode.KBackquote, Key.Backquote},
            {KeyCode.KA, Key.A},
            {KeyCode.KB, Key.B},
            {KeyCode.KC, Key.C},
            {KeyCode.KD, Key.D},
            {KeyCode.KE, Key.E},
            {KeyCode.KF, Key.F},
            {KeyCode.KG, Key.G},
            {KeyCode.KH, Key.H},
            {KeyCode.KI, Key.I},
            {KeyCode.KJ, Key.J},
            {KeyCode.KK, Key.K},
            {KeyCode.KL, Key.L},
            {KeyCode.KM, Key.M},
            {KeyCode.KN, Key.N},
            {KeyCode.KO, Key.O},
            {KeyCode.KP, Key.P},
            {KeyCode.KQ, Key.Q},
            {KeyCode.KR, Key.R},
            {KeyCode.KS, Key.S},
            {KeyCode.KT, Key.T},
            {KeyCode.KU, Key.U},
            {KeyCode.KV, Key.V},
            {KeyCode.KW, Key.W},
            {KeyCode.KX, Key.X},
            {KeyCode.KY, Key.Y},
            {KeyCode.KZ, Key.Z},
            {KeyCode.KCapslock, Key.CapsLock},
            {KeyCode.KF1, Key.F1},
            {KeyCode.KF2, Key.F2},
            {KeyCode.KF3, Key.F3},
            {KeyCode.KF4, Key.F4},
            {KeyCode.KF5, Key.F5},
            {KeyCode.KF6, Key.F6},
            {KeyCode.KF7, Key.F7},
            {KeyCode.KF8, Key.F8},
            {KeyCode.KF9, Key.F9},
            {KeyCode.KF10, Key.F10},
            {KeyCode.KF11, Key.F11},
            {KeyCode.KF12, Key.F12},
            {KeyCode.KPrintscreen, Key.PrintScreen},
            {KeyCode.KScrolllock, Key.ScrollLock},
            {KeyCode.KPause, Key.Pause},
            {KeyCode.KInsert, Key.Insert},
            {KeyCode.KHome, Key.Home},
            {KeyCode.KPageup, Key.PageUp},
            {KeyCode.KDelete, Key.Delete},
            {KeyCode.KEnd, Key.End},
            {KeyCode.KPagedown, Key.PageDown},
            {KeyCode.KRight, Key.Right},
            {KeyCode.KLeft, Key.Left},
            {KeyCode.KDown, Key.Down},
            {KeyCode.KUp, Key.Up},
            {KeyCode.KNumlockclear, Key.NumLock},
            {KeyCode.KKPDivide, Key.KeypadDivide},
            {KeyCode.KKPMultiply, Key.KeypadMultiply},
            {KeyCode.KKPMinus, Key.KeypadSubtract},
            {KeyCode.KKPPlus, Key.KeypadAdd},
            {KeyCode.KKPEnter, Key.KeypadEnter},
            {KeyCode.KKP1, Key.Keypad1},
            {KeyCode.KKP2, Key.Keypad2},
            {KeyCode.KKP3, Key.Keypad3},
            {KeyCode.KKP4, Key.Keypad4},
            {KeyCode.KKP5, Key.Keypad5},
            {KeyCode.KKP6, Key.Keypad6},
            {KeyCode.KKP7, Key.Keypad7},
            {KeyCode.KKP8, Key.Keypad8},
            {KeyCode.KKP9, Key.Keypad9},
            {KeyCode.KKP0, Key.Keypad0},
            //{KeyCode.KKPPeriod, Key.KeypadPeriod},
            {KeyCode.KApplication, Key.SuperLeft},
            //{KeyCode.KPower, Key.Power},
            {KeyCode.KKPEquals, Key.KeypadEqual},
            {KeyCode.KF13, Key.F13},
            {KeyCode.KF14, Key.F14},
            {KeyCode.KF15, Key.F15},
            {KeyCode.KF16, Key.F16},
            {KeyCode.KF17, Key.F17},
            {KeyCode.KF18, Key.F18},
            {KeyCode.KF19, Key.F19},
            {KeyCode.KF20, Key.F20},
            {KeyCode.KF21, Key.F21},
            {KeyCode.KF22, Key.F22},
            {KeyCode.KF23, Key.F23},
            {KeyCode.KF24, Key.F24},
            //{KeyCode.KExecute, Key.Execute},
            //{KeyCode.KHelp, Key.Help},
            {KeyCode.KMenu, Key.Menu},
            //{KeyCode.KSelect, Key.Select},
            //{KeyCode.KStop, Key.Stop},
            //{KeyCode.KAgain, Key.Again},
            //{KeyCode.KUndo, Key.Undo},
            //{KeyCode.KCut, Key.Cut},
            //{KeyCode.KCopy, Key.Copy},
            //{KeyCode.KPaste, Key.Paste},
            //{KeyCode.KFind, Key.Find},
            //{KeyCode.KMute, Key.Mute},
            //{KeyCode.KVolumeup, Key.Volumeup},
            //{KeyCode.KVolumedown, Key.Volumedown},
            //{KeyCode.KKPComma, Key.KPComma},
            //{KeyCode.KKPEqualsas400, Key.KPEqualsas400},
            //{KeyCode.KAlterase, Key.Alterase},
            //{KeyCode.KSysreq, Key.Sysreq},
            //{KeyCode.KCancel, Key.Cancel},
            //{KeyCode.KClear, Key.Clear},
            //{KeyCode.KPrior, Key.Prior},
            //{KeyCode.KReturn2, Key.Return},
            //{KeyCode.KSeparator, Key.Separator},
            //{KeyCode.KOut, Key.Out},
            //{KeyCode.KOper, Key.Oper},
            //{KeyCode.KClearagain, Key.Clearagain},
            //{KeyCode.KCrsel, Key.Crsel},
            //{KeyCode.KExsel, Key.Exsel},
            //{KeyCode.KKP00, Key.KP00},
            //{KeyCode.KKP000, Key.KP000},
            //{KeyCode.KThousandsseparator, Key.Thousandsseparator},
            //{KeyCode.KDecimalseparator, Key.Decimalseparator},
            //{KeyCode.KCurrencyunit, Key.Currencyunit},
            //{KeyCode.KCurrencysubunit, Key.Currencysubunit},
            //{KeyCode.KKPLeftparen, Key.KPLeftparen},
            //{KeyCode.KKPRightparen, Key.KPRightparen},
            //{KeyCode.KKPLeftbrace, Key.KPLeftbrace},
            //{KeyCode.KKPRightbrace, Key.KPRightbrace},
            //{KeyCode.KKPTab, Key.KPTab},
            //{KeyCode.KKPBackspace, Key.KPBackspace},
            //{KeyCode.KKPA, Key.KPA},
            //{KeyCode.KKPB, Key.KPB},
            //{KeyCode.KKPC, Key.KPC},
            //{KeyCode.KKPD, Key.KPD},
            //{KeyCode.KKPE, Key.KPE},
            //{KeyCode.KKPF, Key.KPF},
            //{KeyCode.KKPXor, Key.KPXor},
            //{KeyCode.KKPPower, Key.KPPower},
            //{KeyCode.KKPPercent, Key.KPPercent},
            //{KeyCode.KKPLess, Key.KPLess},
            //{KeyCode.KKPGreater, Key.KPGreater},
            //{KeyCode.KKPAmpersand, Key.KPAmpersand},
            //{KeyCode.KKPDblampersand, Key.KPDblampersand},
            //{KeyCode.KKPVerticalbar, Key.KPVerticalbar},
            //{KeyCode.KKPDblverticalbar, Key.KPDblverticalbar},
            //{KeyCode.KKPColon, Key.KPColon},
            //{KeyCode.KKPHash, Key.KPHash},
            //{KeyCode.KKPSpace, Key.KPSpace},
            //{KeyCode.KKPAT, Key.KPAT},
            //{KeyCode.KKPExclam, Key.KPExclam},
            //{KeyCode.KKPMemstore, Key.KPMemstore},
            //{KeyCode.KKPMemrecall, Key.KPMemrecall},
            //{KeyCode.KKPMemclear, Key.KPMemclear},
            //{KeyCode.KKPMemadd, Key.KPMemadd},
            //{KeyCode.KKPMemsubtract, Key.KPMemsubtract},
            //{KeyCode.KKPMemmultiply, Key.KPMemmultiply},
            //{KeyCode.KKPMemdivide, Key.KPMemdivide},
            //{KeyCode.KKPPlusminus, Key.KPPlusminus},
            //{KeyCode.KKPClear, Key.KPClear},
            //{KeyCode.KKPClearentry, Key.KPClearentry},
            //{KeyCode.KKPBinary, Key.KPBinary},
            //{KeyCode.KKPOctal, Key.KPOctal},
            //{KeyCode.KKPDecimal, Key.KPDecimal},
            //{KeyCode.KKPHexadecimal, Key.KPHexadecimal},
            {KeyCode.KLctrl, Key.ControlLeft},
            {KeyCode.KLshift, Key.ShiftLeft},
            {KeyCode.KLalt, Key.AltLeft},
            //{KeyCode.KLgui, Key.Lgui},
            {KeyCode.KRctrl, Key.ControlRight},
            {KeyCode.KRshift, Key.ShiftRight},
            {KeyCode.KRalt, Key.AltRight},
            //{KeyCode.KRgui, Key.Rgui},
            //{KeyCode.KMode, Key.Mode},
            //{KeyCode.KAudionext, Key.Audionext},
            //{KeyCode.KAudioprev, Key.Audioprev},
            //{KeyCode.KAudiostop, Key.Audiostop},
            //{KeyCode.KAudioplay, Key.Audioplay},
            //{KeyCode.KAudiomute, Key.Audiomute},
            //{KeyCode.KMediaselect, Key.Mediaselect},
            //{KeyCode.KWww, Key.Www},
            //{KeyCode.KMail, Key.Mail},
            //{KeyCode.KCalculator, Key.Calculator},
            //{KeyCode.KComputer, Key.Computer},
            //{KeyCode.KACSearch, Key.ACSearch},
            //{KeyCode.KACHome, Key.ACHome},
            //{KeyCode.KACBack, Key.ACBack},
            //{KeyCode.KACForward, Key.ACForward},
            //{KeyCode.KACStop, Key.ACStop},
            //{KeyCode.KACRefresh, Key.ACRefresh},
            //{KeyCode.KACBookmarks, Key.ACBookmarks},
            //{KeyCode.KBrightnessdown, Key.Brightnessdown},
            //{KeyCode.KBrightnessup, Key.Brightnessup},
            //{KeyCode.KDisplayswitch, Key.Displayswitch},
            //{KeyCode.KKbdillumtoggle, Key.Kbdillumtoggle},
            //{KeyCode.KKbdillumdown, Key.Kbdillumdown},
            //{KeyCode.KKbdillumup, Key.Kbdillumup},
            //{KeyCode.KEject, Key.Eject},
            //{KeyCode.KSleep, Key.Sleep},
            //{KeyCode.KApp1, Key.App1},
            //{KeyCode.KApp2, Key.App2},
            //{KeyCode.KAudiorewind, Key.Audiorewind},
            //{KeyCode.KAudiofastforward, Key.Audiofastforward}
        };
    }
}
